ArenaHistory.Logger = {}
local Logger = ArenaHistory.Logger

Logger.__index = Logger
Logger.name = "default"

Logger.Level = {}
Logger.Level.DEBUG = 1
Logger.Level.INFO = 2
Logger.Level.WARNING = 3
Logger.Level.ERROR = 4

Logger.Level.Message = {"DEBUG", "INFO", "WARNING", "ERROR"}
Logger.Level.Color = {
    "cFF00FF00" --[[ DEBUG: Green --]],
    "cFF00FF00" --[[ INFO: Green --]],
    "cFFFFFF00" --[[ WATNING: Yellow --]],
    "cFFFF0000" --[[ ERROR: Red --]]
}

Logger.Level.minLevel = 10

function Logger.new(name)
  local logger = setmetatable({}, Logger)
  logger.name = name
  return logger
end

function Logger.setLevel(level)
  Logger.Level.minLevel = Logger.Level[level]
end

function Logger:_log(level, message)
  if level >= Logger.Level.minLevel then
    local color = Logger.Level.Color[level]
    local levelMessage = Logger.Level.Message[level]
    print(string.format("|%s %s [%s]: %s|r",
        color, levelMessage, self.name, message))
  end
end

function Logger:debug(pattern, ...)
  self:_log(Logger.Level.DEBUG, string.format(pattern, ...))
end

function Logger:info(pattern, ...)
  self:_log(Logger.Level.INFO, string.format(pattern, ...))
end

function Logger:warning(pattern, ...)
  self:_log(Logger.Level.WARNING, string.format(pattern, ...))
end

function Logger:error(pattern, ...)
  self:_log(Logger.Level.ERROR, string.format(pattern, ...))
end
